nagios_host 'avmajournals.avma.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AVMA',
		'address' => 'avmajournals.avma.org',
		'contact_groups' => 'cs_escalation,avma',
		'notes' => 'AVMA Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/AVMA/pages/1847230493/Server+Setup+-+AVMA'
end
nagios_host 'admin-avmajournals.avma.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AVMA MGMT',
		'address' => 'admin-avmajournals.avma.org',
		'contact_groups' => 'cs_escalation,avma',
		'notes' => 'AVMA Production Management Portal',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/AVMA/pages/1847230493/Server+Setup+-+AVMA'
end
nagios_host 'ams-avmajournals.avma.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AVMA AMS',
		'address' => 'ams-avmajournals.avma.org',
		'contact_groups' => 'cs_escalation,avma',
		'notes' => 'AVMA Production AMS',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/AVMA/pages/1847230493/Server+Setup+-+AVMA'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# checks the homepage of the live AVMA site and checks for the string 'American Veterinary Medical Association'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'avmajournals.avma.org-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'avmajournals.avma.org',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!avma:avma2021!/!"American Veterinary Medical Association"!10!20!',
		'contact_groups' => 'cs_escalation,avma',
		'notes' => 'AVMA Live Site',
		'notes_url' => 'https://avmajournals.avma.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# checks the homepage of the live avma site on the first web node and checks for the string 'American Veterinary Medical Association'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'avmajournals.avma.org-Live Homepage: avma-web-3' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'avmajournals.avma.org',
		'display_name' => 'Live Homepage: avma-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node!avma:avma2021!/!"American Veterinary Medical Association"!10!20!avma-web-3-live!avma-web-3.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,avma',
		'notes' => 'AVMA Live Site: avma-web-3',
		'notes_url' => 'https://avmajournals.avma.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# checks the homepage of the live avma site on the sercond web node and checks for the string 'American Veterinary Medical Association'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'avmajournals.avma.org-Live Homepage: avma-web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'avmajournals.avma.org',
		'display_name' => 'Live Homepage: avma-web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!avma:avma2021!/!"American Veterinary Medical Association"!10!20!avma-web-4-live!avma-web-4.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,avma',
		'notes' => 'AVMA Live Site: avma-web-4',
		'notes_url' => 'https://avmajournals.avma.org'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search of the live AVMA site and checks for the string 'American Veterinary Medical Association'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'avmajournals.avma.org-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'avmajournals.avma.org',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!avma:avma2021!/search!Browse!10!20!',
		'contact_groups' => 'cs_escalation,avma',
		'notes' => 'AVMA Live Site',
		'notes_url' => 'https://avmajournals.avma.org/search'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 1)
# Checks the search of the live avma site on the first web node and checks for the string 'American Veterinary Medical Association'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'avmajournals.avma.org-Live Search: avma-web-3' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'avmajournals.avma.org',
		'display_name' => 'Live search: avma-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node!avma:avma2021!/search!Browse!10!20!avma-web-3-live!avma-web-3.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,avma',
		'notes' => 'AVMA Live Site: avma-web-3',
		'notes_url' => 'https://avmajournals.avma.org/search'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 2)
# Checks the search of the live avma site on the second web node and checks for the string 'American Veterinary Medical Association'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'avmajournals.avma.org-Live Search: avma-web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'avmajournals.avma.org',
		'display_name' => 'Live search: avma-web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!avma:avma2021!/search!Browse!10!20!avma-web-4-live!avma-web-4.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,avma',
		'notes' => 'AVMA Live Site: avma-web-4',
		'notes_url' => 'https://avmajournals.avma.org/search'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW
# checks the content view of the live AVMA site and checks for the string 'American Veterinary Medical Association'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'avmajournals.avma.org-Live content view' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'avmajournals.avma.org',
		'display_name' => 'Live content view',
		'check_command' => 'https_content_check_basic_auth!avma:avma2021!/view/journals/javma/259/8/javma.259.8.874.xml!toy!10!20!',
		'contact_groups' => 'cs_escalation,avma',
		'notes' => 'AVMA Live Site',
		'notes_url' => 'https://avmajournals.avma.org/view/journals/tpmd/104/1/article-p5.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 1)
# checks the content view of the live avma site on the first web node and checks for the string 'American Veterinary Medical Association'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'avmajournals.avma.org-Live content view: avma-web-3' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'avmajournals.avma.org',
		'display_name' => 'Live content view: avma-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node!avma:avma2021!/view/journals/javma/259/8/javma.259.8.874.xml!toy!10!20!avma-web-3-live!avma-web-3.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,avma',
		'notes' => 'AVMA Live Site: avma-web-3',
		'notes_url' => 'https://avmajournals.avma.org/view/journals/tpmd/104/1/article-p5.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 2)
# checks the content view of the live avma site on the sedmond web node and checks for the string 'American Veterinary Medical Association'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'avmajournals.avma.org-Live content view: avma-web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'avmajournals.avma.org',
		'display_name' => 'Live content view: avma-web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!avma:avma2021!/view/journals/javma/259/8/javma.259.8.874.xml!toy!10!20!avma-web-4-live!avma-web-4.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,avma',
		'notes' => 'AVMA Live Site: avma-web-4',
		'notes_url' => 'https://avmajournals.avma.org//view/journals/tpmd/104/1/article-p5.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Login' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'avmajournals.avma.org-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'admin-avmajournals.avma.org',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin-avmajournals.avma.org!/login!avma:avma2021!"AVMA"!20!10',
		'contact_groups' => 'admins_email_only,avma',
		'notes' => 'AVMA Live Loader',
		'notes_url' => 'https://admin-avmajournals.avma.org/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'American Veterinary Medical Association' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'avmajournals.avma.org-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'avmajournals.avma.org',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!staging-avmajournals.avma.org!avma:avma2021!"American Veterinary Medical Association"!20!10',
		'contact_groups' => 'admins_email_only,avma',
		'notes' => 'AVMA Staging Site',
		'notes_url' => 'staging-avmajournals.avma.org'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'AMS' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'avmajournals.avma.org-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ams-avmajournals.avma.org',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams-avmajournals.avma.org!/login!avma:avma2021!AMS!20!10',
		'contact_groups' => 'admins_email_only,avma',
		'notes' => 'AVMA AMX',
		'notes_url' => 'https://ams-avmajournals.avma.org/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'avmajournals.avma.org-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'avmajournals.avma.org',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!avmajournals.avma.org!avma:avma2021!"provisional account"',
		'contact_groups' => 'admins_email_only,avma',
		'notes' => 'AVMA Live Site Failopen',
		'notes_url' => 'https://avmajournals.avma.org/'
end
